summaryrefslogtreecommitdiff
path: root/utils/TableGen/InstrSelectorEmitter.h
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2003-08-07 20:42:23 +0000
committerChris Lattner <sabre@nondot.org>2003-08-07 20:42:23 +0000
commitee858d2a8357e6773553fa11f3502f72a0372f06 (patch)
tree329c63457171488882242f9875841db86fb6d9dc /utils/TableGen/InstrSelectorEmitter.h
parent90825b4b4b6f98e6723423ac1a26f5174202782f (diff)
downloadllvm-ee858d2a8357e6773553fa11f3502f72a0372f06.tar.gz
llvm-ee858d2a8357e6773553fa11f3502f72a0372f06.tar.bz2
llvm-ee858d2a8357e6773553fa11f3502f72a0372f06.tar.xz
Rename all of the "Process" methods to be "read" methods, start the Instantiate method
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@7685 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'utils/TableGen/InstrSelectorEmitter.h')
-rw-r--r--utils/TableGen/InstrSelectorEmitter.h25
1 files changed, 14 insertions, 11 deletions
diff --git a/utils/TableGen/InstrSelectorEmitter.h b/utils/TableGen/InstrSelectorEmitter.h
index a9d7028eb0..8a8734b934 100644
--- a/utils/TableGen/InstrSelectorEmitter.h
+++ b/utils/TableGen/InstrSelectorEmitter.h
@@ -194,21 +194,24 @@ public:
std::map<Record*, NodeType> &getNodeTypes() { return NodeTypes; }
private:
- // ProcessNodeTypes - Process all of the node types in the current
- // RecordKeeper, turning them into the more accessible NodeTypes data
- // structure.
- void ProcessNodeTypes();
+ // ReadNodeTypes - Read in all of the node types in the current RecordKeeper,
+ // turning them into the more accessible NodeTypes data structure.
+ void ReadNodeTypes();
- // ProcessNonTerminals - Read in all nonterminals and incorporate them into
- // our pattern database.
- void ProcessNonterminals();
+ // ReadNonTerminals - Read in all nonterminals and incorporate them into our
+ // pattern database.
+ void ReadNonterminals();
- // ProcessInstructionPatterns - Read in all subclasses of Instruction, and
+ // ReadInstructionPatterns - Read in all subclasses of Instruction, and
// process those with a useful Pattern field.
- void ProcessInstructionPatterns();
+ void ReadInstructionPatterns();
- // ProcessExpanderPatterns - Read in all of the expanded patterns.
- void ProcessExpanderPatterns();
+ // ReadExpanderPatterns - Read in all of the expanded patterns.
+ void ReadExpanderPatterns();
+
+ // InstantiateNonterminals - Instantiate any unresolved nonterminals with
+ // information from the context that they are used in.
+ void InstantiateNonterminals();
};
#endif